# pysqrtrootof3taker
 PySqrtRootOf3Taker - A top class package to compute the square root of 3 in a local environment. (For an industrial environment use ThreeToTheOneHalfPy.)

 ## Instructions

 1. Install

 ```
 pip install pysqrtrootof3taker
 ```

 2. Compute the square root of 3:

 ```python
 from pysqrtof3taker import pysqrtrootof3taker

 # Compute the square root of 3
 print(pysqrtof3taker.compute_square_root_of_3())
 ```
